import numpy as np

# MQTT params
BROKER_HOST = '100.90.57.1'
BROKER_PORT = 1883
PRECISION = np.float64  
CHANNELS = [0, 30, 1, 2, 3, 4]  # Synthetic Stream
NUM_CHANNELS  = len(CHANNELS)
SAMPLE_RATE = 250
